import { forceNumber } from '@peertube/peertube-core-utils';
import { VideoPrivacy, VideoState } from '@peertube/peertube-models';
import { CONFIG } from '../initializers/config.js';
import { isStreamingPlaylist } from '../types/models/index.js';
function getVideoWithAttributes(res) {
    return res.locals.videoAPI || res.locals.videoAll || res.locals.onlyVideo;
}
function extractVideo(videoOrPlaylist) {
    return isStreamingPlaylist(videoOrPlaylist)
        ? videoOrPlaylist.Video
        : videoOrPlaylist;
}
function isPrivacyForFederation(privacy) {
    const castedPrivacy = forceNumber(privacy);
    return castedPrivacy === VideoPrivacy.PUBLIC ||
        (CONFIG.FEDERATION.VIDEOS.FEDERATE_UNLISTED === true && castedPrivacy === VideoPrivacy.UNLISTED);
}
function isStateForFederation(state) {
    const castedState = forceNumber(state);
    return castedState === VideoState.PUBLISHED || castedState === VideoState.WAITING_FOR_LIVE || castedState === VideoState.LIVE_ENDED;
}
function getPrivaciesForFederation() {
    return (CONFIG.FEDERATION.VIDEOS.FEDERATE_UNLISTED === true)
        ? [{ privacy: VideoPrivacy.PUBLIC }, { privacy: VideoPrivacy.UNLISTED }]
        : [{ privacy: VideoPrivacy.PUBLIC }];
}
function getExtFromMimetype(mimeTypes, mimeType) {
    const value = mimeTypes[mimeType];
    if (Array.isArray(value))
        return value[0];
    return value;
}
export { getVideoWithAttributes, extractVideo, getExtFromMimetype, isStateForFederation, isPrivacyForFederation, getPrivaciesForFederation };
//# sourceMappingURL=video.js.map