import { VideoViewsManager } from '../../views/video-views-manager.js';
import { logger } from '../../../helpers/logger.js';
import { audiencify, getAudience } from '../audience.js';
import { getLocalVideoViewActivityPubUrl } from '../url.js';
import { sendVideoRelatedActivity } from './shared/send-utils.js';
async function sendView(options) {
    const { byActor, type, video, viewerIdentifier, transaction } = options;
    logger.info('Creating job to send %s of %s.', type, video.url);
    const activityBuilder = (audience) => {
        const url = getLocalVideoViewActivityPubUrl(byActor, video, viewerIdentifier);
        return buildViewActivity({ url, byActor, video, audience, type });
    };
    return sendVideoRelatedActivity(activityBuilder, { byActor, video, transaction, contextType: 'View', parallelizable: true });
}
export { sendView };
function buildViewActivity(options) {
    const { url, byActor, type, video, audience = getAudience(byActor) } = options;
    return audiencify({
        id: url,
        type: 'View',
        actor: byActor.url,
        object: video.url,
        expires: type === 'viewer'
            ? new Date(VideoViewsManager.Instance.buildViewerExpireTime()).toISOString()
            : undefined
    }, audience);
}
//# sourceMappingURL=send-view.js.map