import { logger } from '../../../../helpers/logger.js';
import { WEBSERVER } from '../../../../initializers/constants.js';
import { UserModel } from '../../../../models/user/user.js';
import { UserNotificationModel } from '../../../../models/user/user-notification.js';
import { UserNotificationType, VideoPrivacy, VideoState } from '@peertube/peertube-models';
import { AbstractNotification } from '../common/abstract-notification.js';
export class NewVideoForSubscribers extends AbstractNotification {
    async prepare() {
        this.users = await UserModel.listUserSubscribersOf(this.payload.VideoChannel.actorId);
    }
    log() {
        logger.info('Notifying %d users of new video %s.', this.users.length, this.payload.url);
    }
    isDisabled() {
        return this.payload.privacy !== VideoPrivacy.PUBLIC || this.payload.state !== VideoState.PUBLISHED || this.payload.isBlacklisted();
    }
    getSetting(user) {
        return user.NotificationSetting.newVideoFromSubscription;
    }
    getTargetUsers() {
        return this.users;
    }
    createNotification(user) {
        const notification = UserNotificationModel.build({
            type: UserNotificationType.NEW_VIDEO_FROM_SUBSCRIPTION,
            userId: user.id,
            videoId: this.payload.id
        });
        notification.Video = this.payload;
        return notification;
    }
    createEmail(to) {
        const channelName = this.payload.VideoChannel.getDisplayName();
        const videoUrl = WEBSERVER.URL + this.payload.getWatchStaticPath();
        return {
            to,
            subject: channelName + ' just published a new video',
            text: `Your subscription ${channelName} just published a new video: "${this.payload.name}".`,
            locals: {
                title: 'New content ',
                action: {
                    text: 'View video',
                    url: videoUrl
                }
            }
        };
    }
}
//# sourceMappingURL=new-video-for-subscribers.js.map