import { CONFIG } from '../../initializers/config.js';
import { OBJECT_STORAGE_PROXY_PATHS, WEBSERVER } from '../../initializers/constants.js';
import { buildKey, getEndpointParsed } from './shared/index.js';
function getInternalUrl(config, keyWithoutPrefix) {
    return getBaseUrl(config) + buildKey(keyWithoutPrefix, config);
}
function getWebVideoPublicFileUrl(fileUrl) {
    const baseUrl = CONFIG.OBJECT_STORAGE.WEB_VIDEOS.BASE_URL;
    if (!baseUrl)
        return fileUrl;
    return replaceByBaseUrl(fileUrl, baseUrl);
}
function getHLSPublicFileUrl(fileUrl) {
    const baseUrl = CONFIG.OBJECT_STORAGE.STREAMING_PLAYLISTS.BASE_URL;
    if (!baseUrl)
        return fileUrl;
    return replaceByBaseUrl(fileUrl, baseUrl);
}
function getHLSPrivateFileUrl(video, filename) {
    return WEBSERVER.URL + OBJECT_STORAGE_PROXY_PATHS.STREAMING_PLAYLISTS.PRIVATE_HLS + video.uuid + `/${filename}`;
}
function getWebVideoPrivateFileUrl(filename) {
    return WEBSERVER.URL + OBJECT_STORAGE_PROXY_PATHS.PRIVATE_WEB_VIDEOS + filename;
}
export { getInternalUrl, getWebVideoPublicFileUrl, getHLSPublicFileUrl, getHLSPrivateFileUrl, getWebVideoPrivateFileUrl, replaceByBaseUrl };
function getBaseUrl(bucketInfo, baseUrl) {
    if (baseUrl)
        return baseUrl;
    return `${getEndpointParsed().protocol}//${bucketInfo.BUCKET_NAME}.${getEndpointParsed().host}/`;
}
const regex = new RegExp('https?://[^/]+');
function replaceByBaseUrl(fileUrl, baseUrl) {
    if (!fileUrl)
        return fileUrl;
    return fileUrl.replace(regex, baseUrl);
}
//# sourceMappingURL=urls.js.map