import { join } from 'path';
import { CONFIG } from '../initializers/config.js';
import { DIRECTORIES, VIDEO_LIVE } from '../initializers/constants.js';
import { isStreamingPlaylist } from '../types/models/index.js';
import { removeFragmentedMP4Ext } from '@peertube/peertube-core-utils';
import { buildUUID } from '@peertube/peertube-node-utils';
import { isVideoInPrivateDirectory } from './video-privacy.js';
function generateWebVideoFilename(resolution, extname) {
    return buildUUID() + '-' + resolution + extname;
}
function generateHLSVideoFilename(resolution) {
    return `${buildUUID()}-${resolution}-fragmented.mp4`;
}
function getLiveDirectory(video) {
    return getHLSDirectory(video);
}
function getLiveReplayBaseDirectory(video) {
    return join(getLiveDirectory(video), VIDEO_LIVE.REPLAY_DIRECTORY);
}
function getHLSDirectory(video) {
    if (isVideoInPrivateDirectory(video.privacy)) {
        return join(DIRECTORIES.HLS_STREAMING_PLAYLIST.PRIVATE, video.uuid);
    }
    return join(DIRECTORIES.HLS_STREAMING_PLAYLIST.PUBLIC, video.uuid);
}
function getHLSRedundancyDirectory(video) {
    return join(DIRECTORIES.HLS_REDUNDANCY, video.uuid);
}
function getHlsResolutionPlaylistFilename(videoFilename) {
    return removeFragmentedMP4Ext(videoFilename) + '.m3u8';
}
function generateHLSMasterPlaylistFilename(isLive = false) {
    if (isLive)
        return 'master.m3u8';
    return buildUUID() + '-master.m3u8';
}
function generateHlsSha256SegmentsFilename(isLive = false) {
    if (isLive)
        return 'segments-sha256.json';
    return buildUUID() + '-segments-sha256.json';
}
function generateTorrentFileName(videoOrPlaylist, resolution) {
    const extension = '.torrent';
    const uuid = buildUUID();
    if (isStreamingPlaylist(videoOrPlaylist)) {
        return `${uuid}-${resolution}-${videoOrPlaylist.getStringType()}${extension}`;
    }
    return uuid + '-' + resolution + extension;
}
function getFSTorrentFilePath(videoFile) {
    return join(CONFIG.STORAGE.TORRENTS_DIR, videoFile.torrentFilename);
}
export { generateHLSVideoFilename, generateWebVideoFilename, generateTorrentFileName, getFSTorrentFilePath, getHLSDirectory, getLiveDirectory, getLiveReplayBaseDirectory, getHLSRedundancyDirectory, generateHLSMasterPlaylistFilename, generateHlsSha256SegmentsFilename, getHlsResolutionPlaylistFilename };
//# sourceMappingURL=paths.js.map