import { move } from 'fs-extra/esm';
import { dirname, join } from 'path';
import { logger } from '../../../../helpers/logger.js';
import { onTranscodingEnded } from '../../../transcoding/ended-transcoding.js';
import { onWebVideoFileTranscoding } from '../../../transcoding/web-transcoding.js';
import { buildNewFile } from '../../../video-file.js';
import { VideoModel } from '../../../../models/video/video.js';
import { lTags } from '../../../object-storage/shared/logger.js';
export async function onVODWebVideoOrAudioMergeTranscodingJob(options) {
    const { video, videoFilePath, privatePayload } = options;
    const videoFile = await buildNewFile({ path: videoFilePath, mode: 'web-video' });
    videoFile.videoId = video.id;
    const newVideoFilePath = join(dirname(videoFilePath), videoFile.filename);
    await move(videoFilePath, newVideoFilePath);
    await onWebVideoFileTranscoding({
        video,
        videoFile,
        videoOutputPath: newVideoFilePath
    });
    if (privatePayload.deleteInputFileId) {
        const inputFile = video.VideoFiles.find(f => f.id === privatePayload.deleteInputFileId);
        if (inputFile) {
            await video.removeWebVideoFile(inputFile);
            await inputFile.destroy();
            video.VideoFiles = video.VideoFiles.filter(f => f.id !== inputFile.id);
        }
        else {
            logger.error('Cannot delete input file %d of video %s: does not exist anymore', privatePayload.deleteInputFileId, video.uuid, Object.assign(Object.assign({}, lTags(video.uuid)), { privatePayload }));
        }
    }
    await onTranscodingEnded({ isNewVideo: privatePayload.isNewVideo, moveVideoToNextState: true, video });
}
export async function loadTranscodingRunnerVideo(runnerJob, lTags) {
    const videoUUID = runnerJob.privatePayload.videoUUID;
    const video = await VideoModel.loadFull(videoUUID);
    if (!video) {
        logger.info('Video %s does not exist anymore after transcoding runner job.', videoUUID, lTags(videoUUID));
        return undefined;
    }
    return video;
}
//# sourceMappingURL=vod-helpers.js.map