import { logger, loggerTagsFactory } from '../../helpers/logger.js';
import { VideoViewerCounters, VideoViewerStats, VideoViews } from './shared/index.js';
const lTags = loggerTagsFactory('views');
export class VideoViewsManager {
    constructor() {
    }
    init() {
        this.videoViewerStats = new VideoViewerStats();
        this.videoViewerCounters = new VideoViewerCounters();
        this.videoViews = new VideoViews();
    }
    async processLocalView(options) {
        const { video, ip, viewEvent, currentTime } = options;
        logger.debug('Processing local view for %s and ip %s.', video.url, ip, lTags());
        await this.videoViewerStats.addLocalViewer({ video, ip, viewEvent, currentTime });
        const successViewer = await this.videoViewerCounters.addLocalViewer({ video, ip });
        const watchTime = await this.videoViewerStats.getWatchTime(video.id, ip);
        const successView = await this.videoViews.addLocalView({ video, watchTime, ip });
        return { successView, successViewer };
    }
    async processRemoteView(options) {
        const { video, viewerId, viewerExpires } = options;
        logger.debug('Processing remote view for %s.', video.url, Object.assign({ viewerExpires, viewerId }, lTags()));
        if (viewerExpires)
            await this.videoViewerCounters.addRemoteViewer({ video, viewerId, viewerExpires });
        else
            await this.videoViews.addRemoteView({ video });
    }
    getViewers(video) {
        return this.videoViewerCounters.getViewers(video);
    }
    getTotalViewers(options) {
        return this.videoViewerCounters.getTotalViewers(options);
    }
    buildViewerExpireTime() {
        return this.videoViewerCounters.buildViewerExpireTime();
    }
    processViewerStats() {
        return this.videoViewerStats.processViewerStats();
    }
    static get Instance() {
        return this.instance || (this.instance = new this());
    }
}
//# sourceMappingURL=video-views-manager.js.map